@@ -1,4 +1,4 @@
-import unittest 
+import unittest
 import os
 import time
 import contextlib
@@ -10,35 +10,39 @@ import funconf
 import virtualbox
 from virtualbox import library
 
-config = funconf.Config(['tests/test_vm.conf', 'test_vm.conf'])
+config = funconf.Config(["tests/test_vm.conf", "test_vm.conf"])
 username = config.machine.username
 password = config.machine.password
 
+
 class TestTestVM(unittest.TestCase):
-    
     def test_lock_vm(self):
         """create a locked session for the test_vm machine"""
         vbox = virtualbox.VirtualBox()
-        
-        # Assert that we can create a lock over a machine 
-        vm = vbox.find_machine('test_vm')
+
+        # Assert that we can create a lock over a machine
+        vm = vbox.find_machine("test_vm")
         s = virtualbox.Session()
         vm.lock_machine(s, virtualbox.library.LockType.shared)
         self.assertTrue(s.state == virtualbox.library.SessionState.locked)
 
-        # Assert we can only lock a session object once 
-        self.assertRaises(library.VBoxErrorInvalidObjectState,
-                        vm.lock_machine,
-                        s, 
-                        virtualbox.library.LockType.shared)
+        # Assert we can only lock a session object once
+        self.assertRaises(
+            library.VBoxErrorInvalidObjectState,
+            vm.lock_machine,
+            s,
+            virtualbox.library.LockType.shared,
+        )
 
         # Assert we can open a second session and can now apply a write lock
         # to the resource machine as it already has a shared lock acquired
         s2 = virtualbox.Session()
-        self.assertRaises(library.VBoxErrorInvalidObjectState,
-                        vm.lock_machine,
-                        s2, 
-                        virtualbox.library.LockType.write)
+        self.assertRaises(
+            library.VBoxErrorInvalidObjectState,
+            vm.lock_machine,
+            s2,
+            virtualbox.library.LockType.write,
+        )
 
         # Assert that we can open a shared lock to the vm which already has
         # a session with a shared lock over it
@@ -53,17 +57,19 @@ class TestTestVM(unittest.TestCase):
 
         # Finally, build a write lock and assert we can not open a shared lock
         vm.lock_machine(s, virtualbox.library.LockType.write)
-        self.assertRaises(library.VBoxErrorInvalidObjectState,
-                        vm.lock_machine,
-                        s2, 
-                        virtualbox.library.LockType.write)
+        self.assertRaises(
+            library.VBoxErrorInvalidObjectState,
+            vm.lock_machine,
+            s2,
+            virtualbox.library.LockType.write,
+        )
         s.unlock_machine()
         self.assertRaises(library.VBoxError, s.unlock_machine)
 
     def test_power_up_down_vm(self):
         """power up than down the test_vm via launch"""
         vbox = virtualbox.VirtualBox()
-        vm = vbox.find_machine('test_vm')
+        vm = vbox.find_machine("test_vm")
         s = virtualbox.Session()
         p = vm.launch_vm_process(s, "headless", "")
         p.wait_for_completion(5000)
@@ -72,10 +78,12 @@ class TestTestVM(unittest.TestCase):
 
 
 CMD_EXE = r"C:\Windows\System32\cmd.exe"
+
+
 class TestGuestSession(unittest.TestCase):
     def setUp(self):
         self.vbox = virtualbox.VirtualBox()
-        self.vm = self.vbox.find_machine('test_vm')
+        self.vm = self.vbox.find_machine("test_vm")
         self._powered_up = False
         if self.vm.state < virtualbox.library.MachineState.running:
             self._powered_up = True
@@ -90,13 +98,11 @@ class TestGuestSession(unittest.TestCase):
                 time.sleep(1)
 
     def test_execute(self):
-        guest = self.session.console.guest.create_session(username, password,
-                                timeout_ms=60*2000)
-        p, o, e = guest.execute(CMD_EXE, [r'/C', 'ping', '127.0.0.1'])
-        self.assertTrue('Pinging' in o)
-        
-        p, o, e = guest.execute(CMD_EXE, [r'/C', 'netstat', '-nao'])
-        self.assertTrue('Active Connections' in o)
-
- 
+        guest = self.session.console.guest.create_session(
+            username, password, timeout_ms=60 * 2000
+        )
+        p, o, e = guest.execute(CMD_EXE, [r"/C", "ping", "127.0.0.1"])
+        self.assertTrue("Pinging" in o)
 
+        p, o, e = guest.execute(CMD_EXE, [r"/C", "netstat", "-nao"])
+        self.assertTrue("Active Connections" in o)
